@@ -43,9 +43,7 @@ docs_create <- function(index, type, id, body, version=NULL, version_type=NULL,
 }
 
 create_PUT <- function(url, query=NULL, body=NULL, callopts) {
-  tt <- PUT(url, mc(make_up(), callopts), query = query, body = body, encode = "json")
-  if (tt$status_code > 202) {
-    if (content(tt)$status == 400) stop(content(tt)$error)
-  }
-  jsonlite::fromJSON(content(tt, as = "text"), FALSE)
+  tt <- PUT(url, c(es_env$headers, mc(make_up(), callopts)), query = query, body = body, encode = "json")
+  geterror(tt)
+  jsonlite::fromJSON(cont_utf8(tt), FALSE)
 }
