@@ -26,8 +26,7 @@
 msearch <- function(x, raw = FALSE, asdf = FALSE, ...) {
   checkconn()
   if (!file.exists(x)) stop("file ", x, " does not exist", call. = FALSE)
-  conn <- es_get_auth()
-  url <- paste0(conn$base, ":", conn$port, '/_msearch')
+  url <- paste0(make_url(es_get_auth()), '/_msearch')
   tt <- POST(url, make_up(), es_env$headers, ..., body = upload_file(x, type = "application/json"), encode = "json")
   geterror(tt)
   res <- cont_utf8(tt)
