@@ -1,9 +1,8 @@
 context("alias")
 
-invisible(tryCatch(elastic::connect(), error = function(e) e))
+invisible(connect())
 
 test_that("alias_get works", {
-  skip_on_cran()
 
   invisible(tryCatch(index_delete("plos", verbose = FALSE), error = function(e) e))
   invisible(index_create("plos", verbose = FALSE))
@@ -17,7 +16,6 @@ test_that("alias_get works", {
 })
 
 test_that("aliases_get works", {
-  skip_on_cran()
 
   c <- aliases_get()
   expect_is(c, "list")
@@ -28,21 +26,18 @@ test_that("aliases_get works", {
 })
 
 test_that("alias_create works", {
-  skip_on_cran()
 
   d <- invisible(alias_create(index = "plos", alias = "howdy"))
   expect_true(d$acknowledged)
 })
 
 test_that("alias_exists works", {
-  skip_on_cran()
 
   expect_false(alias_exists(index = "plos"))
   expect_true(alias_exists(alias = "tables"))
 })
 
 test_that("alias_delete works", {
-  skip_on_cran()
 
   ff <- alias_delete(index = "plos", alias = "tables")
   expect_is(ff, "list")
@@ -51,9 +46,8 @@ test_that("alias_delete works", {
 })
 
 test_that("alias_* functions fail as expected", {
-  skip_on_cran()
 
-  expect_error(alias_get("adfadf"), "missing")
+  expect_error(alias_get(index = "adfadf"), "no such index || IndexMissing")
   expect_error(alias_get(alias = "adfadfs"), "missing")
   expect_error(alias_create("Adfafasd", "adfadf"))
 })
